@@ -11,6 +11,8 @@ import (
 	"sort"
 )
 
+const defaultNumConnections = 1 // number of connections to use by default; may change in the future.
+
 func (cfg DeviceConfiguration) Copy() DeviceConfiguration {
 	c := cfg
 	c.Addresses = make([]string, len(cfg.Addresses))
@@ -49,6 +51,17 @@ func (cfg *DeviceConfiguration) prepare(sharedFolders []string) {
 	}
 }
 
+func (cfg *DeviceConfiguration) NumConnections() int {
+	switch {
+	case cfg.RawNumConnections == 0:
+		return defaultNumConnections
+	case cfg.RawNumConnections < 0:
+		return 1
+	default:
+		return cfg.RawNumConnections
+	}
+}
+
 func (cfg *DeviceConfiguration) IgnoredFolder(folder string) bool {
 	for _, ignoredFolder := range cfg.IgnoredFolders {
 		if ignoredFolder.ID == folder {
